#!/bin/sh

SCRIPT_DIR=`dirname $0`

. /usr/local/bin/fw_common.sh
. $SCRIPT_DIR/oem_def_hw.sh

function print_usage() {
	$ECHO "Usage: `basename $0` [options]"
	echo "  -h, --help: show usage"
	echo "  -a, --all: update all (root file system and DTB file)"
	echo "  -d, --dtb: update DTB file"
	echo "  -r, --rsw: update root file system"
}

function parse_args () {
	unset FW_PRINT_USAGE
	unset FW_UPDATE_RSW
	unset FW_UPDATE_DTB

	while [ "$1" != "" ]; do
		case $1 in
			# general options
			"-h" | "--help")
				FW_PRINT_USAGE=1
				;;
			"-a" | "--all")
				FW_UPDATE_DTB=1
				FW_UPDATE_RSW=1
				$ECHO "requested to update all."
				;;
			"-d" | "--dtb")
				FW_UPDATE_DTB=1
				$ECHO "requested to update dtb."
				;;
			"-r" | "--rsw")
				FW_UPDATE_RSW=1
				$ECHO "requested to update rsw."
				;;
		esac
		shift
	done
}

function update_rsw() {
	local rsw_file="$1".rsw.tgz
	if [ -f $rsw_file ]; then
		$TAR xzf $rsw_file -C /
		$ECHO "$rsw_file extracted."
	else
		$ECHO "no rsw file."
	fi
}

function update_dtb() {
	local dtb_file="$1".dts.dtb
	if [ -f $dtb_file ]; then
		/usr/local/bin/upgrade_partition -q -d -A $dtb_file
		$ECHO "$dtb_file updated."
	else
		$ECHO "no dtb file."
	fi
}

function init_hw_option() {
	local hw_option_name=`find_hw_option_name`
	if [ -z $hw_option_name ]; then
		$ECHO "no hw option"
		return
	fi
	if [ "$FW_UPDATE_DTB" == "1" ]; then
		update_dtb $hw_option_name
	fi
	if [ "$FW_UPDATE_RSW" == "1" ]; then
		update_rsw $hw_option_name
	fi
}

parse_args $@
if [ "$FW_PRINT_USAGE" == "1" ]; then
	print_usage
	exit 0
fi

pushd $SCRIPT_DIR > /dev/null
init_hw_option
popd > /dev/null
