#!/bin/sh

source /etc/profile

###################################################################################
# define WORK_DIR and TARGET_DIR
#----------------------------------------------------------------------------------
WORK_DIR="/etc/oem_def_data"
echo "Working dir : $WORK_DIR"

#TARGET_DIR=`pwd`/work
TARGET_DIR="/"
echo "Target dir : $TARGET_DIR"
#==================================================================================

###################################################################################
# define text color
#----------------------------------------------------------------------------------
NC='\033[0m' # No Color
Bold="\033[1;1m"
Black="\033[1;30m"
Red="\033[1;31m"
Green="\033[1;32m"
Yellow="\033[1;33m"
Blue="\033[1;34m"
Magenta="\033[1;35m"
Cyan="\033[1;36m"
White="\033[1;97m"
#==================================================================================

###################################################################################
# default config file for [access limite]
PATH_ROUTE_TXT=${TARGET_DIR}/etc/sysconfig/route.txt
#----------------------------------------------------------------------------------
DF_FULL_ROUTE=${WORK_DIR}/full_route.txt
DF_LIMIT_ROUTE=${WORK_DIR}/limit_route.txt
DF_FULL_ROUTE_DIGEST=${WORK_DIR}/full_route_digest.txt
DF_LIMIT_ROUTE_DIGEST=${WORK_DIR}/limit_route_digest.txt
#==================================================================================

###################################################################################
# default config file for [user and password]
PATH_DEF_USER_PASS_TXT=${TARGET_DIR}/etc/sysconfig/def_user_pass.txt
PATH_AUTH_TXT=${TARGET_DIR}/etc/sysconfig/auth.txt
PATH_UEXT_TXT=${TARGET_DIR}/etc/sysconfig/uext.txt
PATH_SHADOW=${TARGET_DIR}/etc/shadow
#----------------------------------------------------------------------------------
DF_AUTH_ADMIN_ADMIN_TXT=${WORK_DIR}/auth_admin_admin.txt
DF_AUTH_ADMIN_1TO4_TXT=${WORK_DIR}/auth_admin_1to4.txt
DF_AUTH_ADMIN_1TO6_TXT=${WORK_DIR}/auth_admin_1to6.txt
DF_AUTH_ADMIN_1TO8_TXT=${WORK_DIR}/auth_admin_1to8.txt
DF_AUTH_ADMIN_ADMIN2016_TXT=${WORK_DIR}/auth_admin_admin2016.txt
DF_AUTH_ROOT_IZPASS12_TXT=${WORK_DIR}/auth_root_izpass12.txt
DF_AUTH_ROOT_KOMOTO_TXT=${WORK_DIR}/auth_root_Komoto.txt
DF_AUTH_DW01_DW01_TXT=${WORK_DIR}/auth_dw01_dw01.txt
DF_AUTH_AYCCTV_ATON_TXT=${WORK_DIR}/auth_aycctv_aton.txt
DF_AUTH_UNION_TXT=${WORK_DIR}/auth_root_union.txt

DF_UEXT_ADMIN_ADMIN_TXT=${WORK_DIR}/uext_admin_admin.txt
DF_UEXT_ADMIN_1TO4_TXT=${WORK_DIR}/uext_admin_1to4.txt
DF_UEXT_ADMIN_1TO6_TXT=${WORK_DIR}/uext_admin_1to6.txt
DF_UEXT_ADMIN_1TO8_TXT=${WORK_DIR}/uext_admin_1to8.txt
DF_UEXT_ADMIN_ADMIN2016_TXT=${WORK_DIR}/uext_admin_admin2016.txt
DF_UEXT_ROOT_IZPASS12_TXT=${WORK_DIR}/uext_root_izpass12.txt
DF_UEXT_ROOT_KOMOTO_TXT=${WORK_DIR}/uext_root_Komoto.txt
DF_UEXT_DW01_DW01_TXT=${WORK_DIR}/uext_dw01_dw01.txt
DF_UEXT_AYCCTV_ATON_TXT=${WORK_DIR}/uext_aycctv_aton.txt
DF_UEXT_UNION_TXT=${WORK_DIR}/uext_root_union.txt

DF_SHADOW_ADMIN=${WORK_DIR}/shadow_admin
DF_SHADOW_1TO4=${WORK_DIR}/shadow_1to4
DF_SHADOW_1TO6=${WORK_DIR}/shadow_1to6
DF_SHADOW_1TO8=${WORK_DIR}/shadow_1to8
DF_SHADOW_ADMIN2016=${WORK_DIR}/shadow_admin2016
DF_SHADOW_IZPASS12=${WORK_DIR}/shadow_izpass12
DF_SHADOW_KOMOTO=${WORK_DIR}/shadow_Komoto
DF_SHADOW_DW01=${WORK_DIR}/shadow_dw01
DF_SHADOW_AYCCTV=${WORK_DIR}/shadow_aycctv
DF_SHADOW_UNION=${WORK_DIR}/shadow_union
#==================================================================================

###################################################################################
# default config file for [server name]
PATH_NAMES_CONF=${TARGET_DIR}/etc/sysconfig/names.conf
#==================================================================================


###################################################################################
#PATH_RTPRTSP=${TARGET_DIR}/opt/nss/etc/FwConf/rtsp.conf
#DF_RTPRTSP_BASE=${WORK_DIR}/rtsp-base
#==================================================================================
#PATH_IPCCTVDNS=${TARGET_DIR}/opt/nss/etc/ascd.conf
#DF_IPCCTVDNS_BASE=${WORK_DIR}/ascd-base
#==================================================================================
#PATH_INETD_CONF=${TARGET_DIR}/etc/inetd.conf
#DF_COSTAR_INETD_CONF=${WORK_DIR}/inetd_disable.conf
#==================================================================================
#PATH_IFUP=${TARGET_DIR}/etc/sysconfig/network-scripts/ifup-eth
#DF_IFUP_ENEO=${WORK_DIR}/ifup-eth-eneo
#==================================================================================
#PATH_DEF_COMS=${TARGET_DIR}/etc/sysconfig/defcoms.conf
#DF_COM_MODE="c"
#DF_AUX_MODE="p"
#WEB_FD_FLAG=0
###################################################################################

OEM_DEF_INIT_LOG=/etc/sysconfig/oem_def_init.log

###################################################################################
# Define the defnet.eth0 file for marking of set default network configuration
# it is used in "~/FlexWatchV42/source/NetCtl/fwnetctl_main.c"
#DEF_NET_INIT_LOG=/etc/NetworkManager/system-connections/defnet.eth0
###################################################################################

###################################################################################
#Function : log()
#==================================================================================
function log() {
	printf "[$(date '+%Y.%m.%d-%H:%M:%S')] $* \n" >> $OEM_DEF_INIT_LOG
	printf "[$(date '+%Y.%m.%d-%H:%M:%S')] $* \n" >&2
}

###################################################################################
#Function : printf_green()
#==================================================================================
function printf_green() {
	printf "${Green}${*}${NC}\n" >&2
}

###################################################################################
#Function : get_oem_code()
#==================================================================================
function get_oem_code() {
	local PNCODE=`grep SYF_STR1 /proc/driver/sy_basic_conf`
#	echo "$PNCODE"
	local OEM_PNCODE=${PNCODE:39:2}
	local OEM_PNCODE_SZ=${#OEM_PNCODE}
	log "OEM_PNCODE:$OEM_PNCODE"
	log "OEM_PNCODE_SZ:$OEM_PNCODE_SZ"
	if [ $OEM_PNCODE_SZ -lt 2 ]; then
		log "Wrong OEM code : $"
	fi

	printf "$OEM_PNCODE" >&1

	return 0;
}

###################################################################################
#Function : get_security_code()
#==================================================================================
function get_security_code() {
	local PNCODE=`grep SYF_STR1 /proc/driver/sy_basic_conf`
#	echo "$PNCODE"
	local SECURITY_PNCODE=${PNCODE:48:1}
	local SECURITY_PNCODE_SZ=${#SECURITY_PNCODE}
	log "SECURITY_PNCODE:$SECURITY_PNCODE"
	log "SECURITY_PNCODE_SZ:$SECURITY_PNCODE_SZ"
	if [ $SECURITY_PNCODE_SZ -lt 1 ]; then
		log "Wrong SECURITY code : $"
	fi

	printf "$SECURITY_PNCODE" >&1

	return 0;
}


###################################################################################
#Function : set_def_user_pass()
#==================================================================================
function set_def_user_pass() {
	local DEF_USER=$1
	local DEF_PASS=$2
	echo "DEF_USER="$DEF_USER > $PATH_DEF_USER_PASS_TXT
	echo "DEF_PASS="$DEF_PASS >> $PATH_DEF_USER_PASS_TXT
	sync
	return 0;
}

###################################################################################
#Function : static_network()
#==================================================================================
function static_network() {
	local IPADDR=$1
	local NETMASK=$2
	local GATWAY=$3

	fwnetctl --ifname eth0 --static $IPADDR $NETMASK $GATWAY --force skip
#	touch $DEF_NET_INIT_LOG
	sync
	return 0;
}

###################################################################################
#Function : def_dhcp_network()
#==================================================================================
function def_dhcp_network() {
	fwnetctl --dhcp --force skip
#	touch $DEF_NET_INIT_LOG
	sync
	return 0;
}

###################################################################################
#Function : static_dns()
#==================================================================================
function static_dns() {
	local DNS1=$1
	local DNS2=$2

	fwnetctl --ifname eth0 --dns $DNS1 $DNS2 --force skip
	sync
	return 0;
}

###################################################################################
#Function : def_dns()
#==================================================================================
function def_dns() {

	fwnetctl --ifname eth0 --dns 168.126.63.1 168.126.63.2 --force skip
	sync
	return 0;
}
#==================================================================================


###################################################################################
#Function : Time zone related
#==================================================================================
TZ_CONF=/etc/sysconfig/tz.conf
TZ_LIST=/usr/share/zone.list
TZ_TGZ=/usr/share/zone.tar.gz

function is_valid_tz(){
        IS_VALID=`grep -c ^$1$ $TZ_LIST`
        return $IS_VALID
}

function change_tz(){
        WORK_DIR=/tzwork

        mkdir $WORK_DIR
        cd $WORK_DIR
        tar xzf $TZ_TGZ

        cp $WORK_DIR/zoneinfo/$1 /etc/sysconfig/localtime
        echo "TIMEZONE=$1" > ${TZ_CONF}
        cd /
        rm -rf $WORK_DIR
}
#==================================================================================


# if already OEM default config is maid, exit
if [ -f $OEM_DEF_INIT_LOG ]; then
	log "OEM Default configuration already done."
	exit 0
fi

log "FlexWatch OEM default configuration"

set_def_user_pass root root

# remove all connections for clearing old connections
rm /etc/NetworkManager/system-connections/*

CurrentOEMCode="$(get_oem_code)"
CurrentSecurityCode="$(get_security_code)"
echo "CurrentOEMCode: $CurrentOEMCode"
echo "CurrentSecurityCode: $CurrentSecurityCode"
printf "Set OEM Configuration: "
case $CurrentOEMCode in
	00 ) # SEYEON (Default NTSC - Static)
		printf_green "FlexWatch"
		static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		def_dns;		
		;;
	01 ) # SEYEON (Default PAL - Static)
		printf_green "FlexWatch"
		static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		def_dns;		
		;;
	02 ) # SEYEON (Default NTSC - DHCP)
		printf_green "FlexWatch"
		def_dhcp_network;	
		;;
	03 ) # SEYEON (Default PAL - DHCP)
		printf_green "FlexWatch"
		def_dhcp_network;	
		;;
	04 ) # Orion Technology(Full Access)
		echo "SERVER_NAME=\"IPVM\"" > $PATH_NAMES_CONF
		printf_green "Orion Technology(Full Access)"
		static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		def_dns;
##		mk_ifcfg eth1 static 11.20.30.40 255.255.255.0 11.20.30.0 11.20.30.255 yes
##		mk_ifcfg ra0 static 10.20.30.40 255.255.255.0 10.20.30.0 10.20.30.255 no
		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		;;
	05 ) # Orion Technology(Limited Access)
		echo "SERVER_NAME=\"IPVM\"" > $PATH_NAMES_CONF
		printf_green "Orion Technology(Limited Access)"
##		mk_ifcfg eth1 static 11.20.30.40 255.255.255.0 11.20.30.0 11.20.30.255 yes
##		mk_ifcfg ra0 static 10.20.30.40 255.255.255.0 10.20.30.0 10.20.30.255 no
		;;
#	06 ) #
	07 ) # TBT - High Temperature Support
		printf_green "TBT - High Temperature Support"
		def_dhcp_network;	
		def_dns;
		;;
	08 ) # TBT - Normal Temperature Support
		printf_green "TBT - Normal Temperature Support"
		def_dhcp_network;	
		def_dns;
		;;
#	09 ) #
	0A ) # Costar Video
		printf_green "Costar Video"
		static_network 192.168.0.129 255.255.255.0 192.168.0.1;
		def_dns;
##		edit_rtsp 1
		;;
	0a ) # TENP_PLANING (iSemocon - Japan two SD)
		printf_green "TENP_PLANING (iSemocon - Japan two SD)"
		static_network 192.168.2.101 255.255.255.0 192.168.2.1;
		def_dns;
##		echo "nameserver 192.168.2.1" > /etc/resolv.conf
##		echo "nameserver 8.8.8.8" >> /etc/resolv.conf
		;;
	0B ) # Dongyang Unitech
##		. /var/log/fw_sensor_pncode
##		case "$FW_SENSOR" in
##			0l)
##				DF_COM_MODE="n"
##				;;
##			*)
##				DF_COM_MODE="c"
##		esac
##		DF_AUX_MODE="p"
##		WEB_FD_FLAG=1
		if [ "$CurrentSecurityCode" == "1" ]; then
			printf_green "Dongyang Unitech-TTA"
			cp -a $DF_LIMIT_ROUTE_DIGEST $PATH_ROUTE_TXT	
		else
			printf_green "Dongyang Unitech"	
			cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		fi

		static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		def_dns;
		;;
	0[bc] ) # Cynix PAL/NTSC
		printf_green "Cynix PAL/NTSC"
		static_network 192.168.10.100 255.255.255.0 192.168.10.1;
		def_dns;
		;;
#	0C ) # Family Dollar
	0D ) # Orion Technology-VIEWZ(Full Access)
		echo "SERVER_NAME=\"VIEWZ\"" > $PATH_NAMES_CONF
		printf_green "Orion T (full access)"
		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		;;
	0d ) # Orion Technology-VIEWZ(Limited Access)
		echo "SERVER_NAME=\"VIEWZ\"" > $PATH_NAMES_CONF
		printf_green "Orion T (limited access)"
		;;
	0[Ee] ) # RONIX 50/60Hz
		printf_green "RONIX 50/60Hz"
		static_network 192.168.1.10 255.255.255.0 192.168.1.1;
		def_dns;
##		cp -a $DF_RTPRTSP_BASE $PATH_RTPRTSP
##		edit_rtsp 1
		;;
	0[Ff] ) # Eneo/Eneo Dual DO (50 Hz)
		printf_green "Eneo/Eneo Dual DO (50 Hz)"
		static_network 192.168.1.10 255.255.255.0 192.168.1.1;
		def_dns;
##		cp -a $DF_RTPRTSP_BASE $PATH_RTPRTSP
##		cp -af $DF_IFUP_ENEO $PATH_IFUP
##		edit_rtsp 1
		;;
	0G ) # URC
		printf_green "URC"
		;;
	0g ) # Biges
		printf_green "Biges"
		static_network 192.168.0.251 255.255.248.0 192.168.0.1;
		def_dns;
		;;
	0H ) # Vitek
		printf_green "Vitek"
##		DEFAULT_TZ=US/Pacific
##		is_valid_tz $DEFAULT_TZ
##		if  [ $? -ne 1 ]; then
##			echo "$DEFAULT_TZ is not valid time zone"
##			exit 1
##		fi
##		change_tz $DEFAULT_TZ
		;;
#	0h ) # Hyosung
	0I)  # GPI360
        printf_green "GPI360"
        cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		def_dhcp_network;
		def_dns;
        ;;
	0i)  # GPI360
        printf_green "GPI360"
        cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		static_network 192.168.0.100 255.255.255.0 192.168.0.1;
		def_dns;
        ;;
	0J ) # Micro Digital - Camera (Default NTSC)
		printf_green "Micro Digital - Camera (Default NTSC)"
		;;
#	0j ) # Micro Digital - Camera (Default PAL)
#	0K ) # Micro Digital - NVR
#	0k ) # Youngkook
	0L ) # Micro Digital - iVideon (Default NTSC)
		printf_green "Micro Digital - iVideon (Default NTSC)"
		def_dns;
		;;
#	0l ) # Micro Digital - iVideon (Default PAL)
#	0M ) # Micro Digital - 3G Modem (Default NTSC)
#	0m ) # Micro Digital - 3G Modem (Default PAL)
	0N ) # Union
		printf_green "Union"
		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT;
		/bin/sed -i 's/ListenStream=23/ListenStream=6423/' /usr/lib/systemd/system/telnet.socket;
		echo "Telnet Port Changed"
		set_def_user_pass root B785-i_SK_Union#
		cp -a $DF_AUTH_UNION_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_UNION_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_UNION $PATH_SHADOW
		/bin/sync;
		;;
	0n ) # Neocom
		printf_green "Neocom"
		static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		def_dns;
		;;
#	0O ) # TNH
	0o ) # UGCCTV(Youguan)
		printf_green "UGCCTV(Youguan) "
		static_network 192.168.1.10 255.255.255.0 192.168.1.1;
		def_dns;
		set_def_user_pass admin admin
		cp -a $DF_AUTH_ADMIN_ADMIN_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_ADMIN_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_ADMIN $PATH_SHADOW
		;;
#	0P ) # IST
#	0p ) # Koditec
#	0Q ) # Lucoms
	0q ) # InMotion
		printf_green "InMotion"
		def_dns;
##		DEFAULT_TZ=US/Central
##		is_valid_tz $DEFAULT_TZ
##		if  [ $? -ne 1 ]; then
##			echo "$DEFAULT_TZ is not valid time zone"
##			exit 1
##		fi
##		change_tz $DEFAULT_TZ
		;;
#	0R ) # Monitor Closely
#	0r ) # Mone S&C
	0S ) # Ikegami
		printf_green "Ikegami"
		static_network 192.168.1.100 255.255.255.0 192.168.1.1;
		def_dns;
##		DEFAULT_TZ=Asia/Tokyo
##		is_valid_tz $DEFAULT_TZ
##		if  [ $? -ne 1 ]; then
##			echo "$DEFAULT_TZ is not valid time zone"
##			exit 1
##		fi
##		change_tz $DEFAULT_TZ
		;;
	0s ) # Samsung
		echo "SERVER_NAME=\"CCTV_CAMERA\"" > $PATH_NAMES_CONF
		printf_green "Samsung"
		;;
#	0T ) # IIST
#	0t ) # Camtron NTSC
	0U ) # Digital Watchdog
		printf_green "Digital Watchdog"
##		DEFAULT_TZ=US/Pacific
##		is_valid_tz $DEFAULT_TZ
##		if  [ $? -ne 1 ]; then
##			echo "$DEFAULT_TZ is not valid time zone"
##			exit 1
##		fi
##		change_tz $DEFAULT_TZ
		;;
#	0u ) # Camtron PAL
#	0V ) # CameraTimes
	0v ) # InnoTech - Rev-E(H.264 Fix)
		printf_green "InnoTech - Rev-E(H.264 Fix)"
		static_network 192.168.0.120 255.255.255.0 192.168.0.1;
		def_dns;
		;;
	0W ) # Wonwoo
		printf_green "Wonwoo"
		static_network 192.168.82.2 255.255.255.0 192.168.82.1;
		def_dns;
		;;
	0w ) # KMW
		printf_green "KMW"
		static_network 192.168.0.201 255.255.0.0 192.168.0.254;
		def_dns;
		set_def_user_pass admin kmwdigitalsw
		cp -a $DF_AUTH_ADMIN_KMWDIGITALSW_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_KMWDIGITALSW_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_KMWDIGITALSW $PATH_SHADOW
                /usr/bin/systemctl start telnet.socket; /usr/bin/systemctl enable telnet.socket; /usr/bin/systemctl start ftp.socket; /usr/bin/systemctl enable ftp.socket;
                echo "Telnet/FTP Enabled"
                /bin/sync;	
		;;
#	0X ) # Micro Digital - 4Ch Encoder
#	0x ) # Qtum (Wonwoo + Qtum)
#	0Y ) # Convex
	0y ) # Semocon
		printf_green "Semocon"
		static_network 192.168.0.100 255.255.255.0 192.168.0.1;
		def_dns;
		;;
	0Z ) # Gyeyoung(FW3170)
		printf_green "Gyeyoung"
		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		;;
	0z ) # Svidia (Dongyang Unitech OEM)
		printf_green "Svidia (Dongyang Unitech OEM)"
##		write_log "Dongyang - Svidia"
		static_network 192.168.1.11 255.255.255.0 192.168.1.1;
		def_dns;
##		echo "nameserver 192.168.1.245" > /etc/resolv.conf
##		echo "nameserver 8.8.8.8" >> /etc/resolv.conf
		;;
#	10 ) #
#	11 ) #
	12 ) # KT&C (KTNC Default Static )
		printf_green "KT&C"
		static_network 172.25.1.100 255.255.255.0 172.25.1.1;
		static_dns 172.25.1.1 172.25.1.1;
                /bin/sync;
		;;
#	13 ) #
#	14 ) #
#	15 ) #
	16 ) # Hucoms2
		printf_green "Hucoms(full access)"
		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		static_network 192.168.10.100 255.255.255.0 192.168.10.1;
		def_dns;
		;;
#	17 ) #
#	18 ) #
#	19 ) #
#	1A ) # SKB - Production
#	1a ) #
#	1B ) # SKB - Shipping
#	1b ) # Cynix - S1 PAL
	1C ) # Dongyang Unitech
##		. /var/log/fw_sensor_pncode
##		case "$FW_SENSOR" in
##			0l)
##				DF_COM_MODE="n"
##				;;
##			*)
##				DF_COM_MODE="c"
##		esac
##		DF_AUX_MODE="p"
##		WEB_FD_FLAG=1
		if [ "$CurrentSecurityCode" == "1" ]; then
			printf_green "Dongyang Unitech-TTA"
			cp -a $DF_LIMIT_ROUTE_DIGEST $PATH_ROUTE_TXT		
		else
			printf_green "Dongyang Unitech"	
			cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		fi

		static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		def_dns;
		;;
#	1c ) # Cynix - S1 NTSC
#	1D ) # VIEWZ-HDMI/WX
	1d ) # Dongyang Unitech
##		. /var/log/fw_sensor_pncode
##		case "$FW_SENSOR" in
##			0l)
##				DF_COM_MODE="n"
##				;;
##			*)
##				DF_COM_MODE="c"
##		esac
##		DF_AUX_MODE="p"
##		WEB_FD_FLAG=1
		if [ "$CurrentSecurityCode" == "1" ]; then
			printf_green "Dongyang Unitech-TTA"
			cp -a $DF_LIMIT_ROUTE_DIGEST $PATH_ROUTE_TXT
		else
			printf_green "Dongyang Unitech"	
			cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		fi
		;;
#	1E ) # Entoss
#	1e ) #
	1F ) # FS Networks
		printf_green "FS Networks"
		static_network 192.168.1.2 255.255.255.0 192.168.1.1;
		def_dns;
		;;
#	1f ) #
	1G ) # Telme Electronics
		printf_green "Telme Electronics Inc"
		static_network 192.168.0.200 255.255.255.0 192.168.0.1;
		def_dns;
		;;
	1g ) # GJD
		printf_green "GJD"
		static_network 192.168.0.11 255.255.255.0 192.168.0.1;
		def_dns;
		;;
	1H ) # Cynix - Honeywell
		set_def_user_pass admin admin
		cp -a $DF_AUTH_ADMIN_ADMIN_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_ADMIN_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_ADMIN $PATH_SHADOW
		printf_green "Cynix - Honeywell"
		static_network 192.168.1.10 255.255.255.0 192.168.1.1;
		def_dns;
		;;
	1h ) # HongSeok
		printf_green "HongSeok"
		static_network 192.168.1.100 255.255.255.0 192.168.1.1;
		def_dns;
		;;
	1I ) # Insight
		if [ "$CurrentSecurityCode" == "1" ]; then
			printf_green "Insight-TTA"
			static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		else
			printf_green "Insight"
			static_network 192.168.0.101 255.255.255.0 192.168.0.1;
		fi
		def_dns;
		;;
#	1i ) #
	1J ) #
		printf_green "JINMYUNG I&C Inc."
		static_network 192.168.1.30 255.255.255.0 192.168.1.1;
		def_dns;
		;;
	1j ) # Japan Security System - JSS
		printf_green "Japan Security System"
		set_def_user_pass admin 1234
		cp -a $DF_AUTH_ADMIN_1TO4_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_1TO4_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_1TO4 $PATH_SHADOW
		def_dhcp_network;
		def_dns;		
		;;
	1K ) # Cynix - Korea Disabled Persons Welfare Society
		set_def_user_pass admin admin
		cp -a $DF_AUTH_ADMIN_ADMIN_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_ADMIN_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_ADMIN $PATH_SHADOW
		printf_green "Cynix - KDP"
		static_network 192.168.1.10 255.255.255.0 192.168.1.1;
		def_dns;
		;;
#	1k ) # KDO
#	1L ) # LED Lighting (Normal Type)
#	1l ) # LED Lighting (Sensor Type)
	1M ) # MyoungSongTech
		printf_green "MyoungSongTech"
		static_network 192.168.0.101 255.255.255.0 192.168.0.1;
		static_dns 8.8.8.8 168.126.63.1;
		;;
	1m ) # Innotech
		set_def_user_pass admin Admin2016
		cp -a $DF_AUTH_ADMIN_ADMIN2016_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_ADMIN2016_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_ADMIN2016 $PATH_SHADOW
		printf_green "Innotech"
		static_network 192.168.11.28 255.255.255.0 192.168.11.1;
		static_dns 192.168.11.1 192.168.11.1;
		;;
#	1N ) # KCL
	1n ) # KOMOTO
		printf_green "KOMOTO"
		set_def_user_pass root Komoto
		cp -a $DF_AUTH_ROOT_KOMOTO_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ROOT_KOMOTO_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_KOMOTO $PATH_SHADOW
		static_network 192.168.0.100 255.255.255.0 192.168.0.1;
		DEFAULT_TZ=Asia/Taipei
		is_valid_tz $DEFAULT_TZ
		if  [ $? -ne 1 ]; then
			echo "$DEFAULT_TZ is not valid time zone"
			exit 1
		fi
		change_tz $DEFAULT_TZ		
		def_dns;
		;;
#	1O ) #
	1o ) # SongWoo
		printf_green "SONGWOO"
		static_network 192.168.0.101 255.255.255.0 192.168.0.1;
		static_dns 8.8.8.8 168.126.63.1;
		;;
	1P ) # PowerTech - 4k
		printf_green "PowerTech - 4k"
		set_def_user_pass admin 123456
		cp -a $DF_AUTH_ADMIN_1TO6_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_1TO6_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_1TO6 $PATH_SHADOW
		;;
	1p ) # Twowins
		printf_green "Twowins"
		static_network 10.20.30.40 255.255.255.0 10.20.30.1;
		def_dns;		
		;;
	1Q ) # ShineView
		printf_green "Shine View"
		static_network 192.168.1.10 255.255.255.0 192.168.1.1;
		def_dns;
		;;
	1q ) #Osang M&ET
		printf_green "Osang M&ET"
		def_dhcp_network;
		def_dns;	
		;;	
	1R ) # Viva Korea
    		printf_green "Viva Korea"
        	static_network 192.168.0.10 255.255.255.0 192.168.0.1;
        	def_dns;
        	;;
	1r ) # Hucoms
		printf_green "Hucoms(full access)"
		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		static_network 192.168.10.100 255.255.255.0 192.168.10.1;
		def_dns;
		;;

#	1S ) # SAT
#	1s ) #
	1T ) # Blue Kite
		printf_green "Blue Kite"
		static_network 192.168.1.4 255.255.0.0 192.168.1.1;
		def_dns;
		;;
	1t ) # Koditec
		printf_green "Koditec"
		static_network 192.168.1.51 255.255.255.0 192.168.1.1;
		def_dns;
		;;
	1U ) # Viva Korea - NTSC
		printf_green "Viva Korea - NTSC"
		static_network 192.168.0.10 255.255.255.0 192.168.0.1;
		def_dns;
		;;
	1u ) # Dream Tech
		printf_green "DreamTech"
		static_network 192.168.0.100 255.255.255.0 192.168.0.1;
		def_dns;
		;;
	1V ) # Viva Korea - PAL
		printf_green "Viva Korea - PAL"
		static_network 192.168.0.11 255.255.255.0 192.168.0.1;
		def_dns;
		;;
	1v ) # Innotech
		set_def_user_pass admin admin
		cp -a $DF_AUTH_ADMIN_ADMIN_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ADMIN_ADMIN_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_ADMIN $PATH_SHADOW
		printf_green "Innotech"
		static_network 192.168.0.120 255.255.255.0 192.168.0.1;
		def_dns;
		;;
#	1W ) # Wearable
	1w ) # DooWon
		printf_green "Doowon"
		set_def_user_pass dw01 dw01
		cp -a $DF_AUTH_DW01_DW01_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_DW01_DW01_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_DW01 $PATH_SHADOW
		;;
#	1X ) #
#	1x ) #
	1Y ) # IndusVision
		printf_green "IndusVision"
		static_network 192.168.1.20 255.255.255.0 192.168.1.1;
		def_dns;
		;;
	1y ) # AnO Onvif Disable(Alpha&Omega)
        printf_green "AnO Onvif Disable(Alpha&Omega)"
        static_network 10.20.30.40 255.255.255.0 10.20.30.1;
        def_dns;
        ;;
#	1Z ) # Zaram Technology
	1z ) # ZAMIR
		printf_green "ZAMIR"
		set_def_user_pass root IZpass12
		cp -a $DF_AUTH_ROOT_IZPASS12_TXT $PATH_AUTH_TXT
		cp -a $DF_UEXT_ROOT_IZPASS12_TXT $PATH_UEXT_TXT
		cp -af $DF_SHADOW_IZPASS12 $PATH_SHADOW
		;;
	*)
		printf_green "FlexWatch"
		if [ "$CurrentSecurityCode" == "1" ]; then
			cp -a $DF_LIMIT_ROUTE_DIGEST $PATH_ROUTE_TXT
			static_network 10.20.30.40 255.255.255.0 10.20.30.1;
			def_dns;		
		else
			static_network 10.20.30.40 255.255.255.0 10.20.30.1;
			def_dns;		
		fi
		
		/bin/sed -i 's/ListenStream=6423/ListenStream=23/' /usr/lib/systemd/system/telnet.socket;
		set_def_user_pass root root
		;;		
esac

OEM_DEF_HW_SH=/etc/oem_def_data/hw/init_oem_def_hw.sh
if [ -x $OEM_DEF_HW_SH ]; then
	$OEM_DEF_HW_SH --rsw
fi

touch $OEM_DEF_INIT_LOG
sync
