#!/bin/sh
#
# Automatically umount partition
# 
# Gil Jin Yang, gjyang@seyeon.co.kr

source /etc/profile

STORAGE_INFO_LOG_FILE="/var/log/storage.info.log"
function log() {
	LOG_FILE=${STORAGE_INFO_LOG_FILE}
	touch $LOG_FILE
	log_file_size=`ls -al ${LOG_FILE} | awk '{printf $5}'`
	if [ "$log_file_size" != "" ]; then 
		if [ $log_file_size -ge 262144 ]; then
			rm $LOG_FILE
			touch $LOG_FILE
			echo "[`date`] ${THIS_SH} $*" > $LOG_FILE
		else
			echo "[`date`] ${THIS_SH} $*" >> $LOG_FILE
		fi
	fi
}

SDCARD_ERROR="1100"
NEED_FORMAT="1101"
SDCARD_MOUNT="1200"
SDCARD_UNMOUNT="1300"
EVENT_SEND_EXEC="/opt/nss/bin/post_event_alarm"
mopts='errors=remount-ro,relatime,noatime,nodiratime'

function post_event(){
	_dir=$1
	_node=$2
	_evt_code=$3
	if [ "$_dir" == "/mnt/C" -a "`echo $_node | rev | cut -c 1`" == "1" ]; then 
		if [ -x $EVENT_SEND_EXEC ]; then 
			log "$EVENT_SEND_EXEC $_evt_code"
			$EVENT_SEND_EXEC $_evt_code
		fi
	fi
}

function check_device() {
	# Check if the device exists, if not but mounted, umount it
	chk_dev=$1
	if ! [ -b $chk_dev ]
	then
		if grep /etc/mtab -qe "^$chk_dev"
		then
			mounted=`cat /etc/mtab |grep $chk_dev | awk '{printf $2}'`
			log "Device $chk_dev is removed, umounting and cleaning ${mounted}"
			umount -l "$mounted"
			log "umount: exitcode=$?"
			post_event "${mounted}" "${chk_dev}" "${SDCARD_UNMOUNT}"
			exitcode=$?
		else
			log "Device $chk_dev doesn't exist anymore"
			post_event "${mounted}" "${chk_dev}" "${SDCARD_UNMOUNT}"
			exitcode=0
		fi

		exit $exitcode
	else
		if blkid -po export $chk_dev 2>&1 | grep -q "No medium found"
		then
			for medium in $(find /dev -name "${chk_dev##*/}[0-9]*")
			do
				mountpoint=$(grep /etc/mtab -e "^${medium}" | awk '{print $2}')
				log "Unmounting device ${medium} from ${mountpoint}"
				log "mountpoint -q ${mountpoint}"
				umount -l "${medium}" && ! mountpoint -q ${mountpoint} 
				post_event "${mounted}" "${chk_dev}" "${SDCARD_UNMOUNT}"
			done
			exit 0
		fi
	fi
}

THIS_SH=`basename $0`
if ! [ "$1" ]; then
	log "missing arguments! a device name must be provided"
	exit 1
else
	DEVNAME=/dev/${1##*/}
	echo "$THIS_SH: $DEVNAME"
fi

check_device $DEVNAME

eval "$(udevadm info -q property --export -p $(udevadm info -qpath -n ${DEVNAME}))";

if [ "$ID_BUS" != "usb" ]; then
	exit 0
fi


# DEC to ASCII
chr() {
	[ "$1" -lt 256 ] || return 1 
	printf "\\$(printf '%03o' "$1")"
}
# ASCII to DEC
ord() {
	LC_CTYPE=C printf '%d' "'$1"
}
set_cfg_env() {
# USAGE: <file> <environment> <value>
	CFG_FILE=$1
	ENV=$2
	ENV_VALUE=$3
	OLD_ENV=`grep "^${ENV}\=" $CFG_FILE`

	if [ "$OLD_ENV" != "" ]; then
		# edit env value to new one
		OLD_ENV=`echo $OLD_ENV | sed s,/,\\\\\\\\\\/,g`
		ENV_VALUE=`echo $ENV_VALUE | sed s,/,\\\\\\\\\\/,g`
		NEW_ENV="$ENV=$ENV_VALUE"
		sed -i -- "s/${ENV}=.*/$NEW_ENV/g" $CFG_FILE
	else
		# create new environment
		NEW_ENV="$ENV=$ENV_VALUE"
		echo "$NEW_ENV" >> $CFG_FILE
	fi
}

# set the mountpoint name according to partition or device name
DEVNODE=`echo "$DEVNAME" | cut -c 6-`
HDDNODE=`echo $DEVNODE | sed 's/[0-9]*//g'`
log "disk-umount DEVNODE=$DEVNODE"
# MNT_NODE_NAME=`chr $(($PORT_NUM+67))`
# MNT_BASE_DIR=/mnt
# MNT_DIR=$MNT_BASE_DIR/$MNT_NODE_NAME

for i in `ls /var/log/storage*.info`; do
	grep -q $DEVNODE $i
	if [ $? -eq 0 ]; then
		MNT_DIR=`cat $i | grep MNT | awk -F '=' '{printf $2}'`
		PORT_NUM_2DIGIT=`cat $i | grep MNT | head -n 1 | grep -E -o '[0-9]{2}'`
		break;
	fi
done
if [ "$MNT_DIR" == "" ]; then
	MNT_DIR=`mount |grep ${DEVNAME} |awk '{printf $3}'`
fi
if [ "$MNT_DIR" == "" ]; then
	umount -l $DEVNAME
	post_event "${MNT_DIR}" "$DEVNAME" "${SDCARD_UNMOUNT}"
	exit 0;
fi
log "disk-umount MNT_DIR=$MNT_DIR"
log "disk-umount PORT_NUM_2DIGIT=$PORT_NUM_2DIGIT"
PORT_NUM=`printf '%d' $PORT_NUM_2DIGIT`
HDD_INFO_FILE="/var/log/storage${PORT_NUM_2DIGIT}.info" 
# remove the mountpoint directory from /mnt/ (if not empty)
if [ -n $mount_point ]; then
	sync
	umount -l $MNT_DIR
	sync
	post_event "${MNT_DIR}" "$DEVNAME" "${SDCARD_UNMOUNT}"
fi
HDD_ENV_NAME=`printf 'HDD%02d' $PORT_NUM`
log "disk-umount HDD_ENV_NAME=$HDD_ENV_NAME"
# remove HDD information
CLEANED_ENV="DEV FORMAT MOUNTED FSTYPE HOSTID MNT PART_TABLE_TYPE PARTED SIZE UUID"

for i in $CLEANED_ENV; do
	log "disk-umount $i"
	if [ "$i" == "FORMAT" -o "$i" == "PARTED" -o "$i" == "SIZE" -o "$i" == "MOUNTED" ]; then
		set_cfg_env $HDD_INFO_FILE "${HDD_ENV_NAME}$i" "0"
	elif [ "$i" == "MNT" ]; then
		set_cfg_env $HDD_INFO_FILE "${HDD_ENV_NAME}$i" $MNT_DIR
	else
		set_cfg_env $HDD_INFO_FILE "${HDD_ENV_NAME}$i" "none"
	fi
	usleep 1000
done

exit 0;
