#!/bin/sh

export PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin

function get_current_time() {
	/bin/date '+%Y/%m/%d - %H:%M:%D'
}

function log_result_of_ntpdate() {
	local desc="$1"

	local fw_log_category_environment=9
	local fw_log_type_modify_time=3
	local fwlogctl=/usr/local/bin/fwlogctl

	/bin/echo "$desc"
	if [ -x $fwlogctl ]; then
		$fwlogctl add -c $fw_log_category_environment -t $fw_log_type_modify_time -d "$desc"
	fi
}

function log_time_changed() {
	local server_addr="$1"
	local prev_time="$2"

	local cur_time=`get_current_time`
	local desc="Time Setting - Auto(NTP Sever Address = $server_addr) : Previous Time = $prev_time / Current Time = $cur_time"
	log_result_of_ntpdate "$desc"
}

function execute_ntpdate() {
	local server_addr=$1
	local max_trials_count=$2
	local wait_time_to_retry=$3

	local trial_count=0
	while [ $trial_count -lt $max_trials_count ]; do
		local prev_time=`get_current_time`
		/usr/sbin/ntpdate $server_addr
		local result=$?
		((trial_count += 1))
		if [ $result -eq 0 ]; then
			log_time_changed $server_addr $prev_time
			return 0
		fi
		/bin/echo "[$trial_count th trial] failed."
		/bin/sleep $wait_time_to_retry
	done
	log_result_of_ntpdate "Failed to do ntpdate."
	return -1
}

function main() {
	local max_retrials_count=5
	local wait_time_to_retry=60

	while [ 1 ]; do
		. /etc/sysconfig/ntp.conf

		if [ $ENABLE = "yes" ]; then
			/bin/echo "ntpdate to be executed..."
			execute_ntpdate $SERVER $max_retrials_count $wait_time_to_retry
		fi

		/bin/sleep $PERIOD
	done
}

main
exit 0
