#!/bin/sh 
#############################################################################################################################
# /usr/local/bin/init_hostapd.sh  
#############################################################################################################################

source /usr/local/bin/wifi_common.sh

function hostapd_defult_config(){
	check_hostapd_conf_value interface wlan0
	check_hostapd_conf_value driver nl80211
	check_hostapd_conf_value hw_mode g
	check_hostapd_conf_value channel 11
	check_hostapd_conf_value macaddr_acl 0
	check_hostapd_conf_value auth_algs 1
	check_hostapd_conf_value wpa 2
	check_hostapd_conf_value wpa_pairwise CCMP
	check_hostapd_conf_value rsn_pairwise CCMP
	check_hostapd_conf_value ignore_broadcast_ssid 0
}

function reload_driver() {
	local down_only=$1

	kill_wpa_supplicant
	kill_proc hostapd
	kill_proc dnsmasq # kill dhcp server
	down_bcmdhd_driver
	if [ "$down_only" -eq 1 ]; then
		set_wlan_mode $WLAN_MODE_DOWN
		return
	fi
	up_bcmdhd_driver "op_mode=2"
}

function init_host_ip() {
	usleep 500000;
	/sbin/ifconfig wlan0 192.168.2.230;
	local is_configured=`/sbin/ifconfig wlan0 | /bin/grep -ic "inet addr:192.168.2.230  Bcast:192.168.2.255  Mask:255.255.255.0"`
	[[ $is_configured -ne 1 ]] && /bin/usleep 500000 && /sbin/ifconfig wlan0 192.168.2.230;
	#/sbin/route add default netmask 255.255.255.0 gw 192.168.2.230 wlan0; RET=$?
	#[[ $RET -ne 0 ]] && /bin/usleep 500000 && /sbin/route add default netmask 255.255.255.0 gw 192.168.2.230 wlan0;
}

function run_hostapd() {
	cp -a $HOSTAPD_CONF $TMP_FW_ENV/hostapd.conf
	kill_proc hostapd
	HOSTAPD=`which hostapd`
	$HOSTAPD -dd $TMP_FW_ENV/hostapd.conf -B
}

function run_dhcp_server() {
	/bin/mkdir -p /etc/dnsmasq.d
	# prevent node scirpt from blocking (see WifiConfigurator.prototype.start() in wifi-configurator.js and RollbackConnection() in config-wifi.sh)
	/usr/sbin/dnsmasq --no-resolv --no-poll --dhcp-range=192.168.2.231,192.168.2.254,1h -i wlan0
	# /usr/sbin/dnsmasq --no-daemon --no-resolv --no-poll --dhcp-range=192.168.2.231,192.168.2.254,1h -i wlan0 & > /dev/null
	#/sbin/route add default gw 192.168.2.230 wlan0;
}

INPUT_ARGS="$*"

F_RELOAD_NET_DRV=0
DOWN_WLAN_DRIVER=0
for i in ${INPUT_ARGS} ;do
	if [ "$i" == "-f" ]; then
		F_RELOAD_NET_DRV=1;
	fi
	if [ "$i" == "-down" ]; then
		DOWN_WLAN_DRIVER=1
	fi
done

if [ $F_RELOAD_NET_DRV -eq 0 ]; then
	WIFI_TYPE=`get_wifi_type`
	if [ $WIFI_TYPE != "$WIFI_TYPE_HOSTAPD" ]; then
		echo "wifi type($WIFI_TYPE) does not support hostapd"
		exit 0
	fi
	if [ $DOWN_WLAN_DRIVER -eq 0 ]; then
		IS_HOSTAPD_MODE=`is_wlan_mode_hostap`
		if [ "$IS_HOSTAPD_MODE" -eq 1 ]; then
			echo "already hostpad mode"
			exit 0
		fi
	fi
fi

set_wlan_mode $WLAN_MODE_HOSTAP

reload_driver $DOWN_WLAN_DRIVER
if [ "$DOWN_WLAN_DRIVER" -eq 1 ]; then
	exit 0
fi

init_host_ip
hostapd_defult_config
run_hostapd
run_dhcp_server

exit 0
