
source /usr/local/bin/fw_common.sh

IPTABLES=/sbin/iptables
SYIPFILTER_CONF=/etc/sysconfig/syipfilter.conf

##################################################
# functions
##################################################
# return: 0=Normal Type, 1=Security Type
function get_security_option() {
	$SPCP 38 1
}

function cleanup_filter() {
	$ECHO "$IPTABLES -F;"
	$ECHO "$IPTABLES -X;"
	$ECHO "$IPTABLES -Z;"
	$ECHO "$IPTABLES -P INPUT ACCEPT;"
	$ECHO "$IPTABLES -P FORWARD ACCEPT;"
	$ECHO "$IPTABLES -P OUTPUT ACCEPT;"
}

function get_https_port() {
    local file_path="/opt/nss/etc/FwConf/https.conf"
    $ECHO `get_property_value_from_file $file_path HTTPS_PORT 443`
}

function get_http_port() {
    local file_path="/etc/sysconfig/webs.conf"
    $ECHO `get_property_value_from_file $file_path Port 80 " "`
}

function get_ftp_port() {
    local file_path="/usr/lib/systemd/system/ftp.socket"
    $ECHO `get_property_value_from_file $file_path ListenStream 21`
}

function get_telnet_port() {
    local file_path="/usr/lib/systemd/system/telnet.socket"
    $ECHO `get_property_value_from_file $file_path ListenStream 23`
}

function get_snmp_port() {
	$ECHO 161
}

function filter_https_service() {
	$ECHO "$IPTABLES -A INPUT -p tcp --dport `get_https_port` -j ACCEPT;"
}

function filter_remote_control_service() {
	local port=$1			# 20, 23, 80, 111 ...
	local protocol=$2		# tcp or udp
	local ips="$3"			# "x.x.x.x y.y.y.y ..."

	if [ "$ips" == "*" ]; then
		$ECHO "$IPTABLES -A INPUT -p $protocol --dport $port -j ACCEPT;"
		return
	fi

	for ip in $ips; do
		$ECHO "$IPTABLES -A INPUT -p $protocol -s $ip --dport $port -j ACCEPT;"
		# $ECHO "$IPTABLES -A INPUT -m iprange --src-range $ip-$ip -p $protocol --dport $port -j ACCEPT;"
	done
	$ECHO "$IPTABLES -A INPUT -p $protocol --dport $port -j DROP;"
}

function filter_remote_control_services() {
	local ips="$1"			# "x.x.x.x y.y.y.y ..."

	if [ -z "$ips" ]; then
		# ignored
		return
	fi

	if [ "$ips" == "*" ]; then
		# ignore DROP *(all ip)
		# no need to do for ACCEPT *, because INPUT table's default policy is ACCEPT
		return
	fi
#	local commands=`filter_https_service`
	local commands="`filter_remote_control_service $(get_https_port) tcp \"$ips\"`"
	commands="$commands`filter_remote_control_service $(get_http_port) tcp \"$ips\"`"
	# commands="$commands`filter_remote_control_service $(get_ftp_port) tcp \"$ips\"`"
	# commands="$commands`filter_remote_control_service $(get_telnet_port) tcp \"$ips\"`"
	commands="$commands`filter_remote_control_service $(get_snmp_port) udp \"$ips\"`"

	$ECHO $commands
}

function filter_normal_services() {
	# ACCEPT/DROP
	local policy=$1
	# "*" or "x.x.x.x-y.y.y.y xx.xx.xx.xx yy.yy.yy.yy ..."
	local ips="$2"

	case "$policy" in
		ACCEPT)
			;;
		DROP)
			;;
		*) # ignored
			return
			;;
	esac

	if [ -z "$ips" ]; then
		# ignored
		return
	fi

	if [ "$ips" == "*" ]; then
		# ignore DROP *(all ip)
		# no need to do for ACCEPT *, because INPUT table's default policy is ACCEPT
		return
	fi

	for ip in $ips; do
		$ECHO "$IPTABLES -A INPUT -m iprange --src-range "$ip" -j $policy;"
	done

	if [ "$policy" == "ACCEPT" ]; then
        $ECHO "$IPTABLES -A INPUT -s 127.0.0.1 -j ACCEPT;"
		$ECHO "$IPTABLES -A INPUT -j DROP;"
	fi
}
