#!/bin/sh
#--------------------------------------------------------------------
# fwupdatepost.sh for ToastCAM
#--------------------------------------------------------------------
source /etc/profile

# firmware upgrade process functions

FWUP_DBG=1

FIRMUP_STATE_FILE=/tmp/fw_upgrade_state.txt

write_firmup_state() {
	echo "PROGRESS=$1;" > $FIRMUP_STATE_FILE
	echo "DESCRIPTION=\"$2\";" >> $FIRMUP_STATE_FILE
	
	if [ "$FWUP_DBG" = "1" ]; then
		echo "---------------------------------------------"
		cat $FIRMUP_STATE_FILE
		echo "---------------------------------------------"
	fi
}

if [ "$1" == "" ]; then
	DEF_FIRM_IMAGE=`/bin/ls /rf_*.tar.gz | tail -n 1`
	if [ "$DEF_FIRM_IMAGE" == "" ]; then
		echo "Can't find firmware image"
		exit 1;
	fi
	FIRMWARE_IMAGE=`realpath $DEF_FIRM_IMAGE`
	if [ "$?" == "0" ]; then
		pushd / > /dev/null
		/bin/ln -sfn "/mnt/rfs${FIRMWARE_IMAGE}" /firmwareimage
		popd > /dev/null
	else
		/bin/echo "[$0] ERROR: can't find firmware image \"$1\""
		exit 1;
	fi
else
	# Got F/W Image from user, create simbolic link
	FIRMWARE_IMAGE=`realpath $1`
	if [ "$?" == "0" ]; then
		pushd / > /dev/null
		/bin/ln -sfn "/mnt/rfs${FIRMWARE_IMAGE}" /firmwareimage
		popd > /dev/null
	else
		/bin/echo "[$0] ERROR: can't find firmware image \"$1\""
		exit 1;
	fi
fi
# fwupdatepost.sh should be excuted at nand-boot mode
IS_UBIFS_BOOT=`/bin/cat /proc/cmdline | /bin/grep -c "ubi.mtd=lnx"`
if [ $IS_UBIFS_BOOT -ne 1  ]; then
	/bin/echo "$0 should be executed at nand-boot mode"
	exit 1
fi

PartitionName="syst"
SYST_MTD=`/bin/cat /proc/mtd | /bin/grep $PartitionName | /usr/bin/awk '{print $1}' | /bin/sed -e s/^mtd// | /bin/sed -e s/\://`

BOOTMODE_TMP=/bootmode.bin
/bin/touch $BOOTMODE_TMP
/bin/echo -n -e \\x01\\x00\\x00\\x00 > $BOOTMODE_TMP
/usr/sbin/flash_eraseall /dev/mtd${SYST_MTD}
/usr/sbin/nandwrite -p /dev/mtd${SYST_MTD} $BOOTMODE_TMP

BOOTMODE_STR=`nanddump --bb=skipbad -l 2048 /dev/mtd${SYST_MTD} | hexdump | /bin/grep ^0000000`
BOOTMODE_L=$(/bin/echo $BOOTMODE_STR | /usr/bin/cut -f2 -d ' ')
BOOTMODE_H=$(/bin/echo $BOOTMODE_STR | /usr/bin/cut -f3 -d ' ')
BOOTMODE=$((10#$BOOTMODE_L))

case "$BOOTMODE" in
	[1])
			/bin/echo "Firmware update BOOTMODE($BOOTMODE)"
			/usr/local/bin/upgrade_partition -q -C "console=ttyS0 root=/dev/ram rw initrd=0x00800000,0x00A00000 ramdisk_size=131072 init=/sbin/init"
			DESC_STR="Change BOOTMODE ... DONE"
			write_firmup_state 40 "$DESC_STR"
			/bin/sync
			exit 0
			;;
	*)
		/bin/echo "[ERROR] BOOTMODE change Failed (BOOTMODE=$BOOTMODE)"
		/bin/echo "[`date`] : [ERROR] BOOTMODE change Failed (BOOTMODE=$BOOTMODE)" >> /root/fwupdatepost.log
		DESC_STR="Change BOOTMODE ... Failed"
		write_firmup_state 40 "$DESC_STR"
		exit 1
		;;
esac

